/*
	Copyright 2006 EarthLink, Inc. All rights reserved.
*/

function ShoppingResult(resultDOM) {

	this.timeStamp = parseInt($a(resultDOM,"tsm"));
	this.sourceLongName = $a(resultDOM,"source-long-name");
	this.sourceShortName = $a(resultDOM,"source-short-name");
	this.sourceId = parseInt($a(resultDOM,"source-id"));
	this.isPrimaryRetailer = $a(resultDOM,"is-primary-retailer");
	
	this.partnerRank = PROVIDERS[this.sourceId].rank;
	
	this.product = new Product($$(resultDOM,"product"),this);
	this.vendor = new Vendor($$(resultDOM,"vendor"));
	
	this.getDetailView = getDetailView;
}//ShoppingResult Object

function getDetailView(offer, rowReference) {
	dv = $("h_detailView").cloneNode(true);
	dv.removeAttribute("id");
	renderDetailView(dv,this,offer,rowReference);
	dv.result = this;
	return dv;
}//getDetailView

function Product(productDOM, srRef) {
	if (productDOM) {
		this.exists = true;
		this.shoppingResult = srRef;
		this.id = getTextData($$(productDOM,"id"));
		this.mpid = getTextData($$(productDOM,"m-pid"));
		this.title = getCleanString(getTextData($$(productDOM,"title")));
		this.truncatedTitle = getTruncatedString(this.title,MAX_TRUNCATED_TITLE_LENGTH);
		this.titleHash = encodeURIComponent(getNormalizedString(this.title)).toLowerCase();
		this.visual = new Visual($$(productDOM,"visual"));
		this.desc = getTextData($$(productDOM,"desc"));
		this.manufacturer = new Manufacturer($$(productDOM,"manufacturer"));
		this.rating = new Rating($$(productDOM,"rating"));
		this.reviews = new Reviews($$(productDOM,"reviews"));
		this.pricing = new Pricing($$(productDOM,"pricing"),this);
	} else {
		this.exists = false;
	}
}//Product Object

function Vendor(vendorDOM) {
	if (vendorDOM) {
		this.exists = true;	
		this.id = getNormalizedString(getTextData($$(vendorDOM,"id")),true);
		this.name = getNormalizedString(getTextData($$(vendorDOM,"name")),true);
		this.visual = new Visual(vendorDOM);
		this.rating = new Rating($$(vendorDOM,"rating"),this);
		this.reviews = new Reviews($$(vendorDOM,"reviews"));
		this.locale = new Locale($$(vendorDOM,"locale"));
	} else {
		this.exists = false;
	}
}//Vendor Object

function Manufacturer(manufacturerDOM) {
	if (manufacturerDOM) {
		this.exists = true;
		this.id = getTextData($$(manufacturerDOM,"id"));
		this.name = getTextData($$(manufacturerDOM, "name"));
	} else {
		this.exists = false;
	}
}

function Visual(visualDOM) {
	if (visualDOM) {
		this.exists = true;
		this.url = getTextData($$($$(visualDOM,"default"),"url"));
		this.width = getTextData($$($$(visualDOM,"default"),"width"));
		this.height = getTextData($$($$(visualDOM,"default"),"height"));
		this.medium_url = getTextData($$($$(visualDOM,"medium"),"url"));
		this.medium_width = getTextData($$($$(visualDOM,"medium"),"width"));
		if (this.medium_width) this.medium_width = parseInt(this.medium_width);
		this.medium_height = getTextData($$($$(visualDOM,"medium"),"height"));
		if (this.medium_height) this.medium_height = parseInt(this.medium_height);
		this.large_url = getTextData($$($$(visualDOM,"large"),"url"));
		this.large_width = getTextData($$($$(visualDOM,"large"),"width"));
		if (this.large_width) this.large_width = parseInt(this.large_width);
		this.large_height = getTextData($$($$(visualDOM,"large"),"height"));
		if (this.large_height) this.large_height = parseInt(this.large_height);
		this.imagesArePreloaded = false;
		/* this part is actually mildly cool :D */
		/* it tells the browser to preload image urls :o */
		/* so when you display it, it goes BLAM */
		/* todo: check for images being enabled/disabled */
		/* we don't want to bog-down dialup users, that's just eveehl. */
		this.preloadImages = function() {
			if (this.url) {
				this.imagePreload = new Image();
				this.imagePreload.src = this.url;
			}
			if (this.medium_url) {
				this.mediumImagePreload = new Image();
				this.mediumImagePreload.src = this.medium_url;
			}
			if (this.large_url) {
				this.largeImagePreload = new Image();
				this.largeImagePreload.src = this.large_url;
			}
			this.imagesArePreloaded = true;
		}//this.preloadImages()
	} else {
		this.exists = false;
	}
}//Visual Object

function Rating(ratingDOM,ratedEntity) {
	if (ratingDOM) {
		this.exists = true;
		
		this.value = getNormalizedString(getTextData(ratingDOM));		
		this.scaleHighest = $a(ratingDOM,"scale-highest");
		this.scaleLowest = $a(ratingDOM,"scale-lowest");
		this.ratedEntity = ratedEntity;
		
	} else {
		this.exists = false;
	}
}//Rating Object

function Reviews(reviewDOM) {
	if (reviewDOM) {
		this.exists = true;

		this.summary = getNormalizedString(getTextData($$(reviewDOM,"summary")),true);
		this.url = getTextData($$(reviewDOM,"url"));
		this.reviewItems = new Array();
		reviewIndex = 0;
		domReviews = $$m($$(reviewDOM,"review_list"),"review");
		for(k=0;domReviews && (domReview=domReviews[k]);k++) {
			this.reviewItems[k] = getTextData(domReview);
		}
	} else {
		this.exists = false;
	}
}//Reviews Object

function Pricing(pricingDOM,productRef) {
	if (pricingDOM) {
		this.exists = true;
		
		this.msrp = getTextData($$(pricingDOM,"msrp"));
		this.msrpCurrencyId = parseInt(getTextData($$(pricingDOM,"msrp-currency-id")));
		if (isNaN(this.msrpCurrencyId)) {
			this.msrpCurrencyId = 1;
		}
		this.msrpCurrency = getCurrency(this.msrpCurrencyId);
		this.offers = new Array();
		offerIndex = 0;
		domOffers = $$m($$(pricingDOM,"offers"),"offer");
		for(j=0;domOffers && (domOffer=domOffers[j]);j++) {
			this.offers[j] = new Offer(domOffer,productRef);
		}
		
	} else {
		this.exists = false;
	}
}//Pricing

function Offer(offerDOM,productRef) {
	if (offerDOM) {
		this.exists = true;
		this.product = productRef;
		this.type = $a(offerDOM,"type");
		this.url = getTextData($$(offerDOM,"url"));
		this.url = this.url.replace(/\^/gi,'%5B');
		this.price = getPriceFloat(getTextData($$(offerDOM,"price")));
		this.currencyId = parseInt(getTextData($$(offerDOM,"currency-id")));
		if (isNaN(this.currencyId)) {
			this.currencyId = 1;
		}
		this.currency = getCurrency(this.currencyId);
		this.timeUtc = new UniversalTimePeriod($$(offerDOM,"time-utc"));
		this.priceRange = new PriceRange($$(offerDOM,"price-range"));
		if (this.priceRange.exists && (this.priceRange.min == this.priceRange.max)) {
			this.price = this.priceRange.min;
		}
		this.savingsFromMsrp = new Savings($$(offerDOM,"savings-from-msrp"));
		this.tax = getPriceFloat(getTextData($$(offerDOM,"tax")));
		this.shipping = new Shipping($$(offerDOM,"shipping"));
		this.total = getPriceFloat(getTextData($$(offerDOM,"total")));
		this.getPriceInfo = getPriceInfo;
		this.getStringPriceInfo = getStringPriceInfo;
		this.getOfferTitle = getOfferTitle;
		this.getOfferTitleTruncated = getOfferTitleTruncated;
	} else {
		this.exists = false;
	}
}//Offer Object

function getPriceInfo() {
	return $t(this.getStringPriceInfo());
}//getPriceInfo

function getStringPriceInfo() {
	pricingInfo = "N/A";	
	if (this.price) {
		pricingInfo = (CURRENCIES[this.currencyId] + getFormattedPrice(this.price) + "");
	} else if (this.priceRange.exists) {
		pricingInfo = CURRENCIES[this.currencyId] + getFormattedPrice(this.priceRange.min) + " - " + CURRENCIES[this.currencyId] + getFormattedPrice(this.priceRange.max);
	}
	return pricingInfo;
}//getStringPriceInfo

function getOfferTitle() {
	return ($t(this.product.title))
}//getOfferTitle

function getOfferTitleTruncated() {
	return ($t(getTruncatedString(this.product.title,MAX_SUGGESTION_MENU_TITLE_LENGTH)));
}

function Shipping(shippingDOM) {
	if (shippingDOM) {
		this.exists = true;
		this.type = getTextData($$(shippingDOM,"type"));
		this.price = getPriceFloat(getTextData($$(shippingDOM,"price")));
	} else {
		this.exists = false;
	}
}//Shipping Object

function PriceRange(priceRangeDOM) {
	if (priceRangeDOM) {
		this.exists = true;
		this.min = getPriceFloat(getTextData($$(priceRangeDOM,"min")));
		this.max = getPriceFloat(getTextData($$(priceRangeDOM,"max")));
	} else {
		this.exists = false;
	}
}//PriceRange Object

function Savings(savingsDOM) {
	if (savingsDOM) {
		this.exists = true;
		this.value = getPriceFloat(getTextData($$(savingsDOM,"value")));
		this.percentage = getTextData($$(savingsDOM,"percentage"));
	} else {
		this.exists = false;
	}
}//Savings Object

function UniversalTimePeriod(periodDOM) {
	if (periodDOM) {
		this.exists = true;
		this.start = getTextData($$(periodDOM,"start"));
		this.end = getTextData($$(periodDOM,"end"));
		if (this.end) {
			this.endDate = getDateFromString(this.end);
		}
	} else {
		this.exists = false;
	}
}//UniversalTimePeriod Object

function Locale(localeDOM) {
	if (localeDOM) {
		this.exists = true;
		this.zip = getNormalizedString(getTextData($$(localeDOM,"zip")),true);
		this.city = getNormalizedString(getTextData($$(localeDOM,"city")),true);
		this.state = getNormalizedString(getTextData($$(localeDOM,"state")),true);
		this.country = countries[getNormalizedString(getTextData($$(localeDOM,"country")),true)];
	} else {
		this.exists = false;
	}
}//Locale Object





